# Nose2 HTML Report
[![Build Status](https://travis-ci.org/mgrijalva/nose2-html-report.svg?branch=master)](https://travis-ci.org/mgrijalva/nose2-html-report)
[![Coverage Status](https://coveralls.io/repos/github/mgrijalva/nose2-html-report/badge.svg?branch=master)](https://coveralls.io/github/mgrijalva/nose2-html-report?branch=master)

### Installation

### Configuration

### Usage
Command line flag:
```
nose2 --html-report
```

If configured via nose2.cfg:
```
nose2
```
